get_credit_registration_expected_ids

Function get_credit_registration_expected_ids 

pub async fn get_credit_registration_expected_ids(
    conn: &mut PgConnection,
    ids: &[Uuid],
) -> ModelResult<HashSet<Uuid>>
Which of ids the push path will create a credit registration for, now or on its next materialise tick: those in credit_registration_eligible_completions.